allele_to_binary: Convert allele sizes to binary

View source: R/allele_binary.R

allele_to_binaryR Documentation

Convert allele sizes to binary

Description

This function converts microsatellite allele sizes into binary matrices.

Usage

allele_to_binary(data, repeat_lengths)

Arguments

data

Input data frame with Marker, Genotype, and allele sizes

repeat_lengths

Repeat length info

Value

A list of binary matrices


ALSBinary documentation built on Aug. 9, 2026, 5:06 p.m.