View source: R/allele_binary.R
| allele_to_binary | R Documentation |
This function converts microsatellite allele sizes into binary matrices.
allele_to_binary(data, repeat_lengths)
data |
Input data frame with Marker, Genotype, and allele sizes |
repeat_lengths |
Repeat length info |
A list of binary matrices
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.